/**
 * Application configuration
 */

import { DateHelper, PresetManager, StringHelper } from '@bryntum/schedulerpro';

const
    zoomLevels = {
        minuteAndHour : 1,
        hourAndDay    : 1
    };

const schedulerConfig = {
    // Limit zoom levels to those which use hours to make filtering non-working time works better in this demo
    presets : PresetManager.records.filter(preset => zoomLevels[preset.id]),

    // A Project holds the data and the calculation engine for Scheduler Pro. It also acts as a CrudManager, allowing
    // loading data into all stores at once
    project : {
        autoLoad  : true,
        transport : {
            load : {
                url : './data/data.json'
            }
        }
    },

    startDate         : '2020-03-23',
    endDate           : '2020-03-28',
    rowHeight         : 90,
    barMargin         : 15,
    eventStyle        : 'border',
    resourceImagePath : './users/',

    // Custom viewPreset (based on 'hourAndDay') that displays a compact 24 hour bottom header
    viewPreset : {
        base              : 'hourAndDay',
        tickWidth         : 30,
        displayDateFormat : 'll HH:mm',
        headers           : [
            {
                unit       : 'day',
                dateFormat : 'ddd DD/MM' //Mon 01/10
            },
            {
                unit       : 'hour',
                dateFormat : 'HH'
            }
        ]
    },

    timeAxis : {
        continuous : false,

        generateTicks(start, end, unit, increment) {
            const ticks = [];

            while (start < end) {

                if (unit !== 'hour' || start.getHours() >= 8 && start.getHours() <= 21) {
                    ticks.push({
                        id        : ticks.length + 1,
                        startDate : start,
                        endDate   : DateHelper.add(start, increment, unit)
                    });
                }

                start = DateHelper.add(start, increment, unit);
            }
            return ticks;
        }
    },

    // Not using the dependencies feature
    dependenciesFeature: false,

    columns : [
        // Column that displays a thumb for the resource
        {
            type : 'resourceInfo',
            text : 'Manager'
        }
    ],

    // Custom event renderer that displays small thumbs for assigned resources
    eventRenderer({ eventRecord, renderData }) {
        const durationColors = {
            0 : 'blue',
            1 : 'indigo',
            2 : 'violet'
        };

        // Project length determines color
        renderData.eventColor = durationColors[Math.min(Math.floor(eventRecord.duration / 9), 2)];

        // Custom content, displays images for assigned resources + event name
        return [
            {
                html : StringHelper.encodeHtml(eventRecord.name)
            },
            {
                className : 'assigned',
                children  : eventRecord.resources.map(resource => ({
                    tag       : 'img',
                    draggable : false,
                    src       : resource.image !== false ? this.resourceImagePath + resource.name.toLowerCase() + '.jpg' : null,
                    dataset   : {
                        resourceId : resource.id
                    }
                }))
            }
        ];
    },

    tbar : [
        // Add a button to filter out non-working time
        {
            ref         : 'filterButton',
            type        : 'button',
            text        : 'Filter out non-working time',
            toggleable  : true,
            icon        : 'b-fa-square',
            pressedIcon : 'b-fa-check-square'
        }
    ]
};

export { schedulerConfig };
